"""
Wrester for obtaining metadata for a given spl observation for UI display.
"""
import json

# pylint: disable=E0401, E0402, R0903
import logging

import pendulum

from aat_wrest.utilities import MDDBConnector, TIME_ZONE, format_interval


class ObservationWrester:
    """
    Class for extracting observation metadata
    """
    def __init__(self, connection, spl: str):
        self.logger = logging.getLogger("aat_wrest")
        self.conn = connection
        self.spl = spl

    def wrest_observation_info(self) -> json:
        """
        Given a product locator, reports the project code, observation length,
        and time in queue for an incomplete observation.

        :return:
        """

        sql = """
        SELECT project_code, mjd_to_timestamp(starttime), mjd_to_timestamp(endtime)
        FROM execution_blocks
        WHERE science_product_locator = %(spl)s
        """

        try:
            cursor = self.conn.cursor()
            cursor.execute(sql, {"spl": self.spl})
            data = cursor.fetchall()

            current_time = pendulum.now().in_timezone(TIME_ZONE)
            start_time = data[0][1]
            end_time_raw = data[0][2]

            pend_endtime = pendulum.instance(end_time_raw)
            print(pend_endtime)
            print(current_time)

            since = current_time.diff(pend_endtime).as_interval()
            print(since)

            make_json = json.dumps(
                {
                    "projectCode": data[0][0],
                    "timeObserved": start_time,
                    "timeInQueue": format_interval(since),
                }, default=str
            )
        finally:
            self.conn.close()

        return make_json
