import pytest
from typing import List

from pyramid.config import Configurator
from pyramid.interfaces import IRoutesMapper


class TestNotificationServer:

    RouteList = List[str]

    @pytest.fixture()
    def notification_routes(self) -> RouteList:
        return [
            "home",
            "view_notifications",
            "create_notification",
            "delete_notification",
            "send_notification"
        ]

    def test_routes_exist(self, test_config: Configurator, notification_routes: RouteList):
        """
        Test that the pyramid config has the proper notification routes in place
        :param test_config: Mock pyramid config for testing
        :param notification_routes: List of expected routes
        """
        test_config.include("notification.routes")
        mapper = test_config.registry.queryUtility(IRoutesMapper)
        route_names = [route.name for route in mapper.get_routes()]
        assert notification_routes == route_names
